# Introduction

Mountaineer 🏔️ is a framework to easily build webapps in Python and React. If you've used either of these languages before for development, we think you'll be right at home.

## Main Features

Each framework has its own unique features and tradeoffs. Mountaineer focuses on developer productivity above all else, with production speed a close second.

- 📝 Typehints up and down the stack: frontend, backend, and database
- 🎙️ Trivially easy client<->server communication, data binding, and function calling
- 🌎 Optimized server rendering for better accessibility and SEO
- 🏹 Static analysis of web pages for strong validation: link validity, data access, etc.
- 🤩 Skip the API or Node.js server just to serve frontend clients

## Getting Started

Head on to the [Quickstart](./quickstart.md) for a full guide on setting up and implementing a new Mountaineer webapp. Our "Learn" section has a few more guides on how to use Mountaineer to its fullest. Then our "API" section has the full docs on all the features and functions available to you.
